Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 43 variants Hyper(Error), Connect(Error), Tls(Error), InvalidDnsNameError(InvalidDnsNameError), HttpRequestBodySize(Option<u64>), DnsTimeout, DnsError { rcode: Option<String>, info_code: Option<u16>, }, DestinationNotFound, DestinationUnavailable, DestinationIpProhibited, DestinationIpUnroutable, ConnectionRefused, ConnectionTerminated, ConnectionTimeout, ConnectionReadTimeout, ConnectionWriteTimeout, ConnectionLimitReached, TlsProtocolError, TlsCertificateError, TlsAlertReceived { alert_id: Option<u8>, alert_message: Option<String>, }, HttpRequestDenied, HttpRequestLengthRequired, HttpRequestMethodInvalid, HttpRequestUriInvalid, HttpRequestUriTooLong, HttpRequestHeaderSectionSize(Option<u32>), HttpRequestHeaderSize { field_name: Option<String>, field_size: Option<u32>, }, HttpRequestTrailerSectionSize(Option<u32>), HttpRequestTrailerSize { field_name: Option<String>, field_size: Option<u32>, }, HttpResponseIncomplete, HttpResponseHeaderSectionSize(Option<u32>), HttpResponseHeaderSize { field_name: Option<String>, field_size: Option<u32>, }, HttpResponseBodySize(Option<u64>), HttpResponseTrailerSectionSize(Option<u32>), HttpResponseTrailerSize { field_name: Option<String>, field_size: Option<u32>, }, HttpResponseTransferCoding(Option<String>), HttpResponseContentCoding(Option<String>), HttpResponseTimeout, HttpUpgradeFailed, HttpProtocolError, LoopDetected, ConfigurationError, InternalError(Option<String>),
}
Error type for wasi:http embedder interactions.

This error type is a superset of the wasip2/wasip3 error types for example and is the error that the embedder interacts with for all operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Hyper(Error)



Connect(Error)



Tls(Error)



InvalidDnsNameError(InvalidDnsNameError)

Available on crate feature default-send-request only.


HttpRequestBodySize(Option<u64>)



DnsTimeout



DnsError

Fields

info_code: Option<u16>


DestinationNotFound



DestinationUnavailable



DestinationIpProhibited



DestinationIpUnroutable



ConnectionRefused



ConnectionTerminated



ConnectionTimeout



ConnectionReadTimeout



ConnectionWriteTimeout



ConnectionLimitReached



TlsProtocolError



TlsCertificateError



TlsAlertReceived

Fields

alert_id: Option<u8>
alert_message: Option<String>


HttpRequestDenied



HttpRequestLengthRequired



HttpRequestMethodInvalid



HttpRequestUriInvalid



HttpRequestUriTooLong



HttpRequestHeaderSectionSize(Option<u32>)



HttpRequestHeaderSize

Fields

field_name: Option<String>
field_size: Option<u32>


HttpRequestTrailerSectionSize(Option<u32>)



HttpRequestTrailerSize

Fields

field_name: Option<String>
field_size: Option<u32>


HttpResponseIncomplete



HttpResponseHeaderSectionSize(Option<u32>)



HttpResponseHeaderSize

Fields

field_name: Option<String>
field_size: Option<u32>


HttpResponseBodySize(Option<u64>)



HttpResponseTrailerSectionSize(Option<u32>)



HttpResponseTrailerSize

Fields

field_name: Option<String>
field_size: Option<u32>


HttpResponseTransferCoding(Option<String>)



HttpResponseContentCoding(Option<String>)



HttpResponseTimeout



HttpUpgradeFailed



HttpProtocolError



LoopDetected



ConfigurationError



InternalError(Option<String>)