pub enum Prepared<'a, T: 'static> {
// some variants omitted
}Available on crate feature
component-model-async only.Expand description
Representation of a “prepared” call for a guest, used to extract the
GuestTaskId before actually executing any handlers.
Right now this is a bit gross since it has to type out a bunch of types by hand.
Implementations