pub enum WorkerStatus {
Idle,
Requests,
PostReturn,
}Available on crate feature
component-model-async only.Expand description
Represents the status of a ProxyHandler worker task.
Variants
Idle
The worker is not handling any requests, nor is it doing any post-return work. It might be doing background work which the guest has indicated can be interrupted and/or abandoned at any time, i.e. does not prevent the instance from being disposed.
Requests
The instance is handling one or more requests, waiting for each to either produce a response or expire.
PostReturn
All requests handled so far have either produced a response or expired, but the guest has post-return work which needs to finish before the instance can be considered idle.