Host

pub trait Host {
    // Required method
    fn handle(
        &mut self,
        request: Resource<OutgoingRequest>,
        options: Option<Resource<RequestOptions>>,
    ) -> Result<Resource<FutureIncomingResponse>, HttpError>;
}
Available on crate feature p2 only.

Required Methods

fn handle( &mut self, request: Resource<OutgoingRequest>, options: Option<Resource<RequestOptions>>, ) -> Result<Resource<FutureIncomingResponse>, HttpError>

This function is invoked with an outgoing HTTP Request, and it returns a resource future-incoming-response which represents an HTTP Response which may arrive in the future.

The options argument accepts optional parameters for the HTTP protocol’s transport layer.

This function may return an error if the outgoing-request is invalid or not allowed to be made. Otherwise, protocol errors are reported through the future-incoming-response.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized> Host for &mut _T

Source

fn handle( &mut self, request: Resource<OutgoingRequest>, options: Option<Resource<RequestOptions>>, ) -> Result<Resource<FutureIncomingResponse>, HttpError>

This function is invoked with an outgoing HTTP Request, and it returns a resource future-incoming-response which represents an HTTP Response which may arrive in the future.

The options argument accepts optional parameters for the HTTP protocol’s transport layer.

This function may return an error if the outgoing-request is invalid or not allowed to be made. Otherwise, protocol errors are reported through the future-incoming-response.

Implementors