pub trait Host {
// Required methods
fn now(&mut self) -> Datetime;
fn resolution(&mut self) -> Datetime;
}p2 only.Required Methods
Sourcefn now(&mut self) -> Datetime
fn now(&mut self) -> Datetime
Read the current value of the clock.
This clock is not monotonic, therefore calling this function repeatedly will not necessarily produce a sequence of non-decreasing values.
The returned timestamps represent the number of seconds since 1970-01-01T00:00:00Z, also known as POSIX’s Seconds Since the Epoch, also known as Unix Time.
The nanoseconds field of the output is always less than 1000000000.
Sourcefn resolution(&mut self) -> Datetime
fn resolution(&mut self) -> Datetime
Query the resolution of the clock.
The nanoseconds field of the output is always less than 1000000000.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: Host + ?Sized> Host for &mut _T
impl<_T: Host + ?Sized> Host for &mut _T
Sourcefn now(&mut self) -> Datetime
fn now(&mut self) -> Datetime
Read the current value of the clock.
This clock is not monotonic, therefore calling this function repeatedly will not necessarily produce a sequence of non-decreasing values.
The returned timestamps represent the number of seconds since 1970-01-01T00:00:00Z, also known as POSIX’s Seconds Since the Epoch, also known as Unix Time.
The nanoseconds field of the output is always less than 1000000000.
Sourcefn resolution(&mut self) -> Datetime
fn resolution(&mut self) -> Datetime
Query the resolution of the clock.
The nanoseconds field of the output is always less than 1000000000.