pub struct WasiHttpCtxView<'a> {
pub ctx: &'a mut WasiHttpCtx,
pub table: &'a mut ResourceTable,
pub hooks: &'a mut dyn WasiHttpHooks,
}Available on crate feature
p2 only.Expand description
Structure which wasi:http Host-style traits are implemented for.
This structure is used by embedders with the WasiHttpView trait’s return
value and is used to provide access to this crate all internals necessary to
implement wasi:http. This is similar to wasmtime_wasi::WasiCtxView
for example.
Fields
ctx: &'a mut WasiHttpCtxA reference to a per-store WasiHttpCtx.
table: &'a mut ResourceTableA reference to a per-store table of resources to store host structures within.
hooks: &'a mut dyn WasiHttpHooksA reference to a per-store set of hooks that can be used to customize
wasi:http behavior.
Implementations
Sourceimpl WasiHttpCtxView<'_>
impl WasiHttpCtxView<'_>
Sourcepub fn new_incoming_request<B>(
&mut self,
scheme: Scheme,
req: Request<B>,
) -> Result<Resource<HostIncomingRequest>>
pub fn new_incoming_request<B>( &mut self, scheme: Scheme, req: Request<B>, ) -> Result<Resource<HostIncomingRequest>>
Create a new incoming request resource.
Sourceimpl WasiHttpCtxView<'_>
impl WasiHttpCtxView<'_>
Sourcepub fn new_response_outparam(
&mut self,
result: Sender<Result<Response<HyperOutgoingBody>, ErrorCode>>,
) -> Result<Resource<HostResponseOutparam>>
pub fn new_response_outparam( &mut self, result: Sender<Result<Response<HyperOutgoingBody>, ErrorCode>>, ) -> Result<Resource<HostResponseOutparam>>
Create a new outgoing response resource.