pub trait Host {
// Required method
fn write_via_stream(
&mut self,
data: StreamReader<u8>,
) -> Result<FutureReader<Result<(), ErrorCode>>>;
}Available on crate feature
p3 only.Required Methods
Sourcefn write_via_stream(
&mut self,
data: StreamReader<u8>,
) -> Result<FutureReader<Result<(), ErrorCode>>>
fn write_via_stream( &mut self, data: StreamReader<u8>, ) -> Result<FutureReader<Result<(), ErrorCode>>>
Write the given stream to stdout.
If the stream’s writable end is dropped this function will either return success once the entire contents of the stream have been written or an error-code representing a failure.
Otherwise if there is an error the readable end of the stream will be dropped and this function will return an error-code.
Implementations on Foreign Types
Sourceimpl<_T: Host + ?Sized> Host for &mut _T
impl<_T: Host + ?Sized> Host for &mut _T
Sourcefn write_via_stream(
&mut self,
data: StreamReader<u8>,
) -> Result<FutureReader<Result<(), ErrorCode>>>
fn write_via_stream( &mut self, data: StreamReader<u8>, ) -> Result<FutureReader<Result<(), ErrorCode>>>
Write the given stream to stdout.
If the stream’s writable end is dropped this function will either return success once the entire contents of the stream have been written or an error-code representing a failure.
Otherwise if there is an error the readable end of the stream will be dropped and this function will return an error-code.