pub trait HostWithStore<T>: HasData + Send {
// Required method
fn send(
accessor: &Accessor<T, Self>,
id: __named_import_name0,
request: Resource<Request>,
) -> impl Future<Output = Result<Resource<Response>, TrappableError<ErrorCode>>> + Send;
}Available on crate feature
p3 only.Required Methods
Sourcefn send(
accessor: &Accessor<T, Self>,
id: __named_import_name0,
request: Resource<Request>,
) -> impl Future<Output = Result<Resource<Response>, TrappableError<ErrorCode>>> + Send
fn send( accessor: &Accessor<T, Self>, id: __named_import_name0, request: Resource<Request>, ) -> impl Future<Output = Result<Resource<Response>, TrappableError<ErrorCode>>> + Send
This function may be used to either send an outgoing request over the network or to forward it to another component.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".