MaybeMutable

Enum MaybeMutable 

pub enum MaybeMutable<T> {
    Mutable(Arc<T>),
    Immutable(Arc<T>),
}
Available on crate feature p3 only.
An Arc, which may be immutable.

In wasi:http resources like fields or request-options may be mutable or immutable. This construct is used to model them efficiently.

Variants



Mutable(Arc<T>)

Clone-on-write, mutable Arc



Immutable(Arc<T>)

Immutable Arc

Implementations

Source

impl<T> MaybeMutable<T>

pub fn new_mutable(v: impl Into<Arc<T>>) -> Self

Construct a mutable MaybeMutable.

pub fn new_mutable_default() -> Self
where T: Default,

Construct a mutable MaybeMutable filling it with default T.

pub fn new_immutable(v: impl Into<Arc<T>>) -> Self

Construct an immutable MaybeMutable.

pub fn into_arc(self) -> Arc<T>

Unwrap MaybeMutable into Arc.

pub fn get_mut(&mut self) -> Option<&mut T>
where T: Clone,

If this MaybeMutable is Mutable, return a mutable reference to it, otherwise return None.

Internally, this will use Arc::make_mut and will clone the underlying value, if multiple strong references to the inner Arc exist.