pub struct RequestOptions {
pub connect_timeout: Option<Duration>,
pub first_byte_timeout: Option<Duration>,
pub between_bytes_timeout: Option<Duration>,
}Expand description
The concrete type behind a wasi:http/types.request-options resource.
Fields
connect_timeout: Option<Duration>How long to wait for a connection to be established.
first_byte_timeout: Option<Duration>How long to wait for the first byte of the response body.
between_bytes_timeout: Option<Duration>How long to wait between frames of the response body.