pub struct WasiHttp;Expand description
A helper struct which implements HasData for the wasi:http APIs.
This can be useful when directly calling add_to_linker functions directly,
such as wasmtime_wasi_http::p3::bindings::http::types::add_to_linker as
the D type parameter. See HasData for more information about the type
parameter’s purpose.
When using this type you can skip the WasiHttpView trait, for example.
Examples
use wasmtime::component::Linker;
use wasmtime::{Engine, Result};
use wasmtime_wasi_http::{WasiHttp, WasiHttpCtxView};
struct MyStoreState {
// ...
}
impl MyStoreState {
fn http(&mut self) -> WasiHttpCtxView<'_> {
// ...
}
}
fn main() -> Result<()> {
let engine = Engine::default();
let mut linker = Linker::new(&engine);
wasmtime_wasi_http::p3::bindings::http::types::add_to_linker::<MyStoreState, WasiHttp>(
&mut linker,
|state| state.http(),
)?;
Ok(())
}Trait Implementations
Sourceimpl HasData for WasiHttp
impl HasData for WasiHttp
Sourcetype Data<'a> = WasiHttpCtxView<'a>
type Data<'a> = WasiHttpCtxView<'a>
The data associated with this trait implementation, chiefly used as a
generic associated type to allow plumbing the
'a lifetime into the
definition here. Read moreSourceimpl<T> HostRequestWithStore<T> for WasiHttp
Available on crate feature p3 only.
impl<T> HostRequestWithStore<T> for WasiHttp
Available on crate feature
p3 only.Sourcefn new(
store: Access<'_, T, Self>,
headers: Resource<Headers>,
contents: Option<StreamReader<u8>>,
trailers: FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>,
options: Option<Resource<RequestOptions>>,
) -> Result<(Resource<Request>, FutureReader<Result<(), ErrorCode>>)>
fn new( store: Access<'_, T, Self>, headers: Resource<Headers>, contents: Option<StreamReader<u8>>, trailers: FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>, options: Option<Resource<RequestOptions>>, ) -> Result<(Resource<Request>, FutureReader<Result<(), ErrorCode>>)>
Construct a new
request with a default method of GET, and
none values for path-with-query, scheme, and authority. Read moreSourcefn consume_body(
store: Access<'_, T, Self>,
req: Resource<Request>,
fut: FutureReader<Result<(), ErrorCode>>,
) -> Result<(StreamReader<u8>, FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>)>
fn consume_body( store: Access<'_, T, Self>, req: Resource<Request>, fut: FutureReader<Result<(), ErrorCode>>, ) -> Result<(StreamReader<u8>, FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>)>
Get body of the Request. Read more
fn drop(store: Access<'_, T, Self>, req: Resource<Request>) -> Result<()>
Sourceimpl<T> HostResponseWithStore<T> for WasiHttp
Available on crate feature p3 only.
impl<T> HostResponseWithStore<T> for WasiHttp
Available on crate feature
p3 only.Sourcefn new(
store: Access<'_, T, Self>,
headers: Resource<Headers>,
contents: Option<StreamReader<u8>>,
trailers: FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>,
) -> Result<(Resource<Response>, FutureReader<Result<(), ErrorCode>>)>
fn new( store: Access<'_, T, Self>, headers: Resource<Headers>, contents: Option<StreamReader<u8>>, trailers: FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>, ) -> Result<(Resource<Response>, FutureReader<Result<(), ErrorCode>>)>
Construct a new
response, with a default status-code of 200.
If a different status-code is needed, it must be set via the
set-status-code method. Read moreSourcefn consume_body(
store: Access<'_, T, Self>,
res: Resource<Response>,
fut: FutureReader<Result<(), ErrorCode>>,
) -> Result<(StreamReader<u8>, FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>)>
fn consume_body( store: Access<'_, T, Self>, res: Resource<Response>, fut: FutureReader<Result<(), ErrorCode>>, ) -> Result<(StreamReader<u8>, FutureReader<Result<Option<Resource<Trailers>>, ErrorCode>>)>
Get body of the Response. Read more
fn drop(store: Access<'_, T, Self>, res: Resource<Response>) -> Result<()>
Sourceimpl<T> HostWithStore<T> for WasiHttp
Available on crate feature p3 only.
impl<T> HostWithStore<T> for WasiHttp
Available on crate feature
p3 only.Auto Trait Implementations
impl Freeze for WasiHttp
impl RefUnwindSafe for WasiHttp
impl Send for WasiHttp
impl Sync for WasiHttp
impl Unpin for WasiHttp
impl UnsafeUnpin for WasiHttp
impl UnwindSafe for WasiHttp