pub struct WasiHttpCtx { /* private fields */ }Expand description
Capture the state necessary for use in the wasi-http API implementation.
Implementations
Sourceimpl WasiHttpCtx
impl WasiHttpCtx
Sourcepub fn set_field_size_limit(&mut self, limit: usize)
pub fn set_field_size_limit(&mut self, limit: usize)
Set the maximum size for any fields resources created by this context.
The limit specified here is roughly a byte limit for the size of the in-memory representation of headers. This means that the limit needs to be larger than the literal representation of headers on the wire to account for in-memory Rust-side data structures representing the header names/values/etc.