WasiHttpNamed

Struct WasiHttpNamed 

pub struct WasiHttpNamed<T>(/* private fields */);
A helper struct which implements HasData for the wasi:http APIs when used in combination with named imports.

This structure is similar in purpose to WasiHttp and is used when using the named_imports module for wasi:http. This structure serves as the D type parameter for add_to_linker functions.

Meaning of the T parameter

Here the T must be something that implements WasiHttpNamedView. The corresponding Data for this type is WasiCtxNamedView which internally will contain &mut T.

Effectively you’re going to implement WasiHttpNamedView for something in your embedding, and that’s the T you’ll fill in here.

Examples

use wasmtime::component::{Linker, Component, ResourceTable};
use wasmtime::{Engine, Result};
use wasmtime_wasi::{NamedId, WasiCtxNamedView};
use wasmtime_wasi_http::{WasiHttpCtx, WasiHttpCtxView, WasiHttpNamed, WasiHttpNamedView};
use wasmtime_wasi_http::p2::bindings::named_imports;
use std::collections::HashMap;

struct MyStoreState {
    table: ResourceTable,
    states: HashMap<NamedId, WasiHttpCtx>,
}

fn main() -> Result<()> {
    let engine = Engine::default();
    let mut linker = Linker::new(&engine);
    let component = Component::new(&engine, "(component)")?;
    let mut name_map = HashMap::new();

    named_imports::wasi::http::outgoing_handler::add_to_linker::<MyStoreState, WasiHttpNamed<MyStoreState>>(
        &mut linker,
        &component,
        |name| {
            let len = name_map.len();
            Ok(NamedId(*name_map.entry(name.to_string()).or_insert(len)))
        },
        |state| WasiCtxNamedView(state),
    )?;
    Ok(())
}

impl WasiHttpNamedView for MyStoreState {
    fn http(&mut self, id: NamedId) -> WasiHttpCtxView<'_> {
        let ctx = self.states.get_mut(&id).expect("state for id");
        WasiHttpCtxView {
            ctx,
            table: &mut self.table,
            hooks: Default::default(),
        }
    }
}