pub enum FieldMapError {
Immutable,
TooManyFields,
TotalSizeTooBig,
InvalidHeaderName,
}Expand description
Errors that can happen when mutating/operating on a FieldMap.
Variants
Immutable
A mutation was attempted when the map is not mutable.
TooManyFields
The map has too many fields and is not allowed to add more.
Note that this is currently a limitation inherited from
[http::HeaderMap].
TotalSizeTooBig
The map’s total size, of keys and values, is too large.
InvalidHeaderName
An invalid header name was attempted to be added.