pub struct HeaderError { /* private fields */ }Available on crate feature
p2 only.Expand description
A wasi:http-specific error type used to represent either a trap or an
types::HeaderError.
Modeled after TrappableError.
Implementations
Sourceimpl HeaderError
impl HeaderError
Sourcepub fn trap(err: impl Into<Error>) -> HeaderError
pub fn trap(err: impl Into<Error>) -> HeaderError
Create a new HeaderError that represents a trap.
Sourcepub fn downcast(self) -> Result<HeaderError>
pub fn downcast(self) -> Result<HeaderError>
Downcast this error to an ErrorCode.
Sourcepub fn downcast_ref(&self) -> Option<&HeaderError>
pub fn downcast_ref(&self) -> Option<&HeaderError>
Downcast this error to a reference to an ErrorCode