pub enum MaybeMutable<T> {
Mutable(Arc<T>),
Immutable(Arc<T>),
}Available on crate feature
p3 only.Expand description
An Arc, which may be immutable.
In wasi:http resources like fields or request-options may be
mutable or immutable. This construct is used to model them efficiently.
Variants
Implementations
Sourceimpl<T> MaybeMutable<T>
impl<T> MaybeMutable<T>
Sourcepub fn new_mutable(v: impl Into<Arc<T>>) -> Self
pub fn new_mutable(v: impl Into<Arc<T>>) -> Self
Construct a mutable MaybeMutable.
Sourcepub fn new_mutable_default() -> Selfwhere
T: Default,
pub fn new_mutable_default() -> Selfwhere
T: Default,
Construct a mutable MaybeMutable filling it with default T.
Sourcepub fn new_immutable(v: impl Into<Arc<T>>) -> Self
pub fn new_immutable(v: impl Into<Arc<T>>) -> Self
Construct an immutable MaybeMutable.
Sourcepub fn into_arc(self) -> Arc<T>
pub fn into_arc(self) -> Arc<T>
Unwrap MaybeMutable into Arc.
Sourcepub fn get_mut(&mut self) -> Option<&mut T>where
T: Clone,
pub fn get_mut(&mut self) -> Option<&mut T>where
T: Clone,
If this MaybeMutable is Mutable,
return a mutable reference to it, otherwise return None.
Internally, this will use Arc::make_mut and will clone the underlying
value, if multiple strong references to the inner Arc exist.