WasiHttpCtxView

Struct WasiHttpCtxView 

pub struct WasiHttpCtxView<'a> {
    pub hooks: &'a mut dyn WasiHttpHooks,
    pub table: &'a mut ResourceTable,
    pub ctx: &'a mut WasiHttpCtx,
}
Basis of implementation of all wasi:http APIs in this crate.

This type provides a temporary view into information such as a WASI resource table, HTTP context information, and embedder-provided hooks if so desired. THe fields in this structure are typically stored within the T of Store<T> and this struct borrows from there. All Host traits generated by bindgen! are implemented for this type.

Fields

hooks: &'a mut dyn WasiHttpHooks

Mutable reference to the WASI HTTP hooks.

Note that default_hooks or Default::default() can be used if you don’t want or need to customize this.

table: &'a mut ResourceTable

Mutable reference to table used to manage resources.

ctx: &'a mut WasiHttpCtx

Mutable reference to the WASI HTTP context.

Implementations

Source

impl WasiHttpCtxView<'_>

pub fn new_incoming_request<B>( &mut self, scheme: Scheme, req: Request<B>, ) -> Result<Resource<HostIncomingRequest>>
where B: Body<Data = Bytes> + Send + 'static, B::Error: Into<Error>,

Available on crate feature p2 only.

Create a new incoming request resource.

Source

impl WasiHttpCtxView<'_>

pub fn new_response_outparam( &mut self, result: Sender<Result<Response<HyperOutgoingBody>, ErrorCode>>, ) -> Result<Resource<HostResponseOutparam>>

Available on crate feature p2 only.

Create a new outgoing response resource.

pub fn new_response_outparam_from_callback( &mut self, callback: impl FnOnce(Result<Response<HyperOutgoingBody>, ErrorCode>) + Send + Sync + 'static, ) -> Result<Resource<HostResponseOutparam>>

Available on crate feature p2 only.

Create a new outgoing response from an FnOnce.